@@ -30,7 +30,7 @@ about_gtktalog ()
   aboutbox = gnome_about_new (PACKAGE, VERSION,
 			      "Copyright (C) 1999-2000  Mathieu VILLEGAS - Yves Mettier",
 			      authors,
-			      _("http://gtktalog.sourceforge.net\n"),
+			      "http://gtktalog.sourceforge.net\n",
 			      DATA_DIR "/gtktalog/icons/logo.xpm");
 
   gtk_widget_show (aboutbox);
