@@ -65,8 +65,7 @@ static GString *message_to_display;
 
 static gboolean vfs_scan_nok;
 
-gint
-spawn_proc (gchar * path, gint narg, gchar ** arg)
+gint spawn_proc (gchar * path, gint narg, gchar ** arg)
 {
   gchar **arg2;
   int i, pid;
@@ -96,8 +95,7 @@ spawn_proc (gchar * path, gint narg, gchar ** arg)
     }
 }
 
-guint
-du_s (gchar * path)
+guint du_s (gchar * path)
 {
   int p[2];
   static gchar buffer[1024];
@@ -171,7 +169,8 @@ set_message_to_display (GString * message)
   is_message_to_display = TRUE;
 }
 
-gboolean eject_disk (CONFIG * my_config)
+gboolean
+eject_disk (CONFIG * my_config)
 {
   int status, pid;
   char *args[2];
@@ -203,37 +202,47 @@ gboolean eject_disk (CONFIG * my_config)
   return (TRUE);
 }
 
-gboolean mount_disk (CONFIG * my_config)
+gboolean
+mount_disk (CONFIG * my_config)
 {
 #if defined(OS_LINUX)
   int pid, status;
   char *args[2];
+  int tries = my_config->mount_retry;
 
   seteuid (getuid ());
   args[0] = my_config->mount->str;
   args[1] = escapespaces (my_config->mount_point->str);
-  pid = spawn_proc (NULL, 2, args);
-  if (pid == -1)
+  printf("%s %s\n", args[0], args[1]);
+  while (tries >= 0)
     {
-      set_message_to_display (g_string_new
-			      (_
-			       ("Could not execute mount program, check your config")));
-      return (FALSE);
-    }
+      pid = spawn_proc (NULL, 2, args);
+      if (pid == -1)
+	{
+	  set_message_to_display (g_string_new
+				  (_
+				   ("Could not execute mount program, check your config")));
+	  return (FALSE);
+	}
 
-  wait4 (pid, &status, 0, NULL);
-  if (WIFEXITED (status) == 0)
-    {
-      set_message_to_display (g_string_new
-			      (_("Mount did not exit normally")));
-      return (FALSE);
+      wait4 (pid, &status, 0, NULL);
+      if (WIFEXITED (status) == 0)
+	{
+	  set_message_to_display (g_string_new
+				  (_("Mount did not exit normally")));
+	  return (FALSE);
+	}
+      if (WEXITSTATUS (status) == 0)
+	{
+	  return (TRUE);
+	}
+      tries--;
+      if (tries >= 0)
+	sleep (MOUNT_RETRY_TIMEOUT);
     }
-  if (WEXITSTATUS (status) != 0)
-    {
-      set_message_to_display (g_string_new (_("Mount failed! Disk in use?")));
-      return (FALSE);
-    }
-  return (TRUE);
+  
+  set_message_to_display (g_string_new (_("Mount failed! Disk in use?")));
+  return (FALSE);
 #elif defined(OS_FREEBSD) || defined(OS_NETBSD)
   int status;
   struct iso_args args;
@@ -251,7 +260,8 @@ gboolean mount_disk (CONFIG * my_config)
 #endif
 }
 
-gboolean umount_disk (CONFIG * my_config)
+gboolean
+umount_disk (CONFIG * my_config)
 {
 #if defined(OS_LINUX)
   int pid, status;
@@ -336,7 +346,8 @@ init_vfs_scan_status (void)
   vfs_scan_nok = FALSE;
 }
 
-gint my_timeout (gpointer data)
+gint
+my_timeout (gpointer data)
 {
   FOLDER *racine = data;
 /*  FILE_DATA *fd;*/
@@ -363,10 +374,10 @@ gint my_timeout (gpointer data)
 /************** If umount and eject have to be in the main thread, remove the comments ********/
 //umount_and_eject_if_necessary();
 /*********************************************************************************************/
-      progress_setCurrent (100);
-      progress_timeout (NULL);
+      progress_setCurrent (100, GNOMEAPPBAR_MAIN);
+      progress_timeout (GINT_TO_POINTER (GNOMEAPPBAR_MAIN));
 
-      reinit_thread_status ();
+      reinit_thread_status (GNOMEAPPBAR_MAIN);
       if (vfs_scan_nok)
 	{
 	  WARNING_DIALOG (_
@@ -376,7 +387,7 @@ gint my_timeout (gpointer data)
     }
   else
     {
-      progress_timeout (NULL);
+      progress_timeout (GINT_TO_POINTER (GNOMEAPPBAR_MAIN));
       gtk_timeout_add (500, my_timeout, racine);
     }
   return (0);
@@ -504,7 +515,8 @@ read_information (gchar * file, gchar * mime)
   return (information_string);
 }
 
-gboolean is_dir_openable (char *dir_name)
+gboolean
+is_dir_openable (char *dir_name)
 {
   DIR *dir;
 
@@ -534,6 +546,7 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
   gchar *infostring;
   static gulong totalDataBlocks = 0;
   gchar *mime;
+  gpointer scan_it;
 
   if (progress_needReset ())
     {
@@ -604,7 +617,7 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
 
 	      /* Progress Bar */
 	      totalDataBlocks += fileinfo.st_size;
-	      progress_setCurrent (totalDataBlocks);
+	      progress_setCurrent (totalDataBlocks, GNOMEAPPBAR_MAIN);
 
 	      mime = NULL;
 	      if (my_config->scan_mime_types)
@@ -613,27 +626,40 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
 		}
 	      if (!mime)
 		mime = g_strdup (gnome_mime_type_or_default (file, NULL));
-
-	      if (getInformation)
+	      if (mime)
 		{
-		  /* use a plugin to get informations about the file */
-		  infostring = read_information (file, mime);
+		  scan_it =
+		    g_tree_lookup (my_config->mime_to_skip_during_a_scan,
+				   mime);
 		}
 	      else
 		{
-		  infostring = NULL;
+		  scan_it = NULL;
 		}
-	      gn = folder_add (racine, parent, fichier->d_name, infostring,
-			       IS_FILE, mime, fileinfo.st_size,
-			       fileinfo.st_ctime, 0, 0);
-	      if (mime)
-		g_free (mime);
-	      if (infostring)
-		g_free (infostring);
-	      if (testvfs != TEST_VFS_NO)
+	      if (GPOINTER_TO_INT (scan_it) != 1)
 		{
-		  if (vfs_read (gn, fichier->d_name, testvfs, racine))
-		    vfs_scan_nok = TRUE;
+		  if (getInformation)
+		    {
+		      /* use a plugin to get informations about the file */
+		      infostring = read_information (file, mime);
+		    }
+		  else
+		    {
+		      infostring = NULL;
+		    }
+		  gn =
+		    folder_add (racine, parent, fichier->d_name, infostring,
+				IS_FILE, mime, fileinfo.st_size,
+				fileinfo.st_ctime, 0, 0);
+		  if (mime)
+		    g_free (mime);
+		  if (infostring)
+		    g_free (infostring);
+		  if (testvfs != TEST_VFS_NO)
+		    {
+		      if (vfs_read (gn, fichier->d_name, testvfs, racine))
+			vfs_scan_nok = TRUE;
+		    }
 		}
 	    }
 	}
@@ -658,7 +684,8 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
   return (vfs_scan_nok);
 }
 
-gboolean check_mounted (CONFIG * my_config)
+gboolean
+check_mounted (CONFIG * my_config)
 {
   FILE *fp;
   char line[1024];
@@ -698,6 +725,9 @@ void *
 start_thread_scan (void *arg)
 {
   FOLDER *racine = arg;
+#if defined(__DEBUG__)
+  GML_log (2, "start_thread_scan()\n");
+#endif
   init_message_to_display ();
 #if defined(USE_PTHREADS)
   pthread_detach (pthread_self ());
@@ -728,6 +758,9 @@ start_thread_scan (void *arg)
 		    ("FIXME: Add error message for error in mounting CD\n");
 		  added_disk_is_ok = ADDED_DISK_NOK;
 		  set_thread_status_to_ended ();
+#if defined(__DEBUG__)
+		  GML_log (2, "Exiting start_thread_scan(): error\n");
+#endif
 #if defined(USE_PTHREADS)
 		  pthread_exit (NULL);
 #endif
@@ -741,9 +774,10 @@ start_thread_scan (void *arg)
 
   /* Get the size of the disk to init the progress bar */
   if (my_config->use_du_s == TRUE)
-    progress_setTotal (du_s (local_foldername));
+    progress_setTotal (du_s (local_foldername), GNOMEAPPBAR_MAIN);
   else
-    progress_setTotal (getStats (escapespaces (my_config->mount_point->str)));
+    progress_setTotal (getStats (escapespaces (my_config->mount_point->str)),
+		       GNOMEAPPBAR_MAIN);
 
   /* Launch the update of the progress bar */
 /*  progress_createTimeout ();*/
@@ -761,6 +795,10 @@ start_thread_scan (void *arg)
   umount_and_eject_if_necessary ();
   set_thread_status_to_ended ();
   racine->is_modified = TRUE;
+#if defined(__DEBUG__)
+  GML_dump (GML_tree_gstrings, FALSE);
+  GML_log (2, "Exiting start_thread_scan(): OK\n");
+#endif
 #if defined(USE_PTHREADS)
   pthread_exit (NULL);
 #endif
