@@ -98,7 +98,9 @@ enable_gnome_button_bar (GtkWidget * window, gpointer data)
   memcpy (&(toolbar[9]), &(general_toolbar[12]), sizeof (GnomeUIInfo));
 
   gnome_app_create_toolbar_with_data (GNOME_APP (window), toolbar, NULL);
-
+#if defined(__DEBUG__)
+  GML_malloc_forget (toolbar);
+#endif
 }
 
 void
