@@ -22,6 +22,8 @@
 #include <config.h>
 #include <gnome.h>
 
-gint compare(const gchar *pattern, const gchar *string, gboolean regex, gboolean case_sensitive);
+gint compare(const gchar *pattern, const gchar *string, gint regex, gboolean case_sensitive);
+char *convert_string_with_slashes (gchar * s);
+GPtrArray *extract_field (const gchar * string, const gchar * separator, GArray *field);
 
 #endif
