@@ -23,6 +23,10 @@
 #include <gnome.h>
 #include <time.h>
 
+#ifdef __DEBUG__
+#include <GML.h>
+#endif
+
 #define USER_CONFIG_DIR "/.gtktalog"
 #define USER_CONFIG_FILE "gtktalog.cf"
 
@@ -76,6 +80,14 @@
 #define CATMASK_CATEGORY	0x2
 #define CATMASK_DESCRIPTION	0x1
 
+#define GNOMEAPPBAR_MAIN	0
+#define GNOMEAPPBAR_SEARCH	1
+
+#define GNOMEAPPBAR_NB		2
+
+#define	MOUNT_RETRY_TIMEOUT	5
+
+
 
 /*********************** structures for the file tree ***********************/
 typedef struct
@@ -175,6 +187,8 @@ typedef struct
   PIX *default_opened_vfs_pix;
   GTree *mime_extensions;
   GTree *mime_vfs_extensions;
+  
+  GTree *mime_to_skip_during_a_scan;
 
   gboolean getInformation;
   gint testvfs;
@@ -196,6 +210,7 @@ typedef struct
   GString *dummy_prog;
   gboolean use_supermount;
   gboolean use_automount;
+  gint mount_retry;
 
   /* Options */
   gboolean use_du_s;
