@@ -95,6 +95,10 @@ fad_create_window (gchar ** fast_name)
 			   GTK_ENTRY (name_entry)->text_length);
   gtk_container_add (GTK_CONTAINER (frame), name_entry);
   gtk_widget_show (name_entry);
+  gtk_widget_grab_focus (name_entry);
+  gnome_dialog_set_default(GNOME_DIALOG(name_window), GNOME_OK);
+  gnome_dialog_editable_enters(GNOME_DIALOG(name_window), 
+      GTK_EDITABLE(name_entry));
 
   button = gnome_dialog_run (GNOME_DIALOG (name_window));
 
