@@ -1139,6 +1139,7 @@ update_file_menu ()
       _gnome_add_file_menu (rf->label, rf->fullname);
       gl = g_list_next (gl);
     }
+    g_free(path);
 }
 
 GList *
@@ -1230,6 +1231,9 @@ build_gui (void)
   GtkWidget *main_vbox;
   GtkWidget *appbar1;
 
+#if defined(__DEBUG__)
+GML_log_point(5,"Entering build_gui()");
+#endif
 /* Main vertical box */
   main_vbox = gtk_vbox_new (FALSE, 1);
   gtk_container_border_width (GTK_CONTAINER (main_vbox), 1);
@@ -1251,7 +1255,7 @@ build_gui (void)
 			    (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (appbar1);
   gnome_app_set_statusbar (GNOME_APP (main_window), appbar1);
-  progress_setGnomeAppBar (appbar1);
+  progress_setGnomeAppBar (appbar1, GNOMEAPPBAR_MAIN);
 
 /* Path entry */
   path_entry = gtk_entry_new_with_max_length (300);
@@ -1286,6 +1290,9 @@ build_gui (void)
 
   gtk_paned_add1 (GTK_PANED (hpaned), ctree_window);
 
+#if defined(__DEBUG__)
+GML_log_point(5,"Leaving build_gui()");
+#endif
 }
 
 void
