@@ -20,9 +20,9 @@
 #include <gnome.h>
 #include "progressbar.h"
 
-static GtkWidget *progress_appbar = NULL;
-static gulong progress_currentValue = 0;
-static gulong progress_totalValue = 100;
+static GtkWidget *progress_appbar[GNOMEAPPBAR_NB];
+static gulong progress_currentValue[GNOMEAPPBAR_NB];
+static gulong progress_totalValue[GNOMEAPPBAR_NB];
 static gboolean progress_INeedReset = TRUE;
 
 void
@@ -31,7 +31,8 @@ progress_reset ()
   progress_INeedReset = FALSE;
 }
 
-gboolean progress_needReset ()
+gboolean
+progress_needReset ()
 {
   return progress_INeedReset;
 }
@@ -40,7 +41,8 @@ gboolean progress_needReset ()
    FIXME: Will take the size of the current filesystem.
         That means it won't work if you only try to catalog a part of a drive
 */
-glong getStats (char *foldername)
+glong
+getStats (char *foldername)
 {
   struct statfs statBuf;
 
@@ -60,23 +62,25 @@ progress_createTimeout ()
 
 /* Update the progress_bar.
    The progress bar must be passed with a gpointer */
-gint progress_timeout (gpointer pstru)
+gint
+progress_timeout (gpointer pstru)
 {
   gfloat new_val;
+  gint reg = GPOINTER_TO_INT (pstru);
 
-  new_val = progress_currentValue / ((float) progress_totalValue);
+  new_val = progress_currentValue[reg] / ((float) progress_totalValue[reg]);
 
   /* Set the new value */
   if (new_val > 0.99)
     new_val = 1;
   if (new_val >= 0)
-    gnome_appbar_set_progress (GNOME_APPBAR (progress_appbar), new_val);
+    gnome_appbar_set_progress (GNOME_APPBAR (progress_appbar[reg]), new_val);
 
   /* Stop the timer */
   if (new_val == 1)
     {
       progress_INeedReset = TRUE;
-      gnome_appbar_set_progress (GNOME_APPBAR (progress_appbar), 0);
+      gnome_appbar_set_progress (GNOME_APPBAR (progress_appbar[reg]), 0);
       return (FALSE);
     }
 
@@ -86,32 +90,31 @@ gint progress_timeout (gpointer pstru)
 }
 
 void
-progress_setTotal (gulong total)
+progress_setTotal (gulong total, gint reg)
 {
-  progress_totalValue = total;
+  progress_totalValue[reg] = total;
 }
 
 void
-progress_setCurrent (gulong current)
+progress_setCurrent (gulong current, gint reg)
 {
-  progress_currentValue = current;
+  progress_currentValue[reg] = current;
 }
 
-gulong
-progress_getCurrent ()
+gulong progress_getCurrent (gint reg)
 {
-  return progress_currentValue;
+  return progress_currentValue[reg];
 }
 
 void
-progress_setStatus (gchar * msg)
+progress_setStatus (gchar * msg, gint reg)
 {
-  gnome_appbar_set_status (GNOME_APPBAR (progress_appbar), msg);
-  gnome_appbar_refresh (GNOME_APPBAR (progress_appbar));
+  gnome_appbar_set_status (GNOME_APPBAR (progress_appbar[reg]), msg);
+  gnome_appbar_refresh (GNOME_APPBAR (progress_appbar[reg]));
 }
 
 void
-progress_setGnomeAppBar (GtkWidget * appbar)
+progress_setGnomeAppBar (GtkWidget * appbar, gint reg)
 {
-  progress_appbar = appbar;
+  progress_appbar[reg] = appbar;
 }
