@@ -28,6 +28,7 @@
 #    include <sys/mount.h>
 #    include <isofs/cd9660/cd9660_mount.h>
 #endif
+#include "config_common.h"
 #include <gnome.h>
 
 
@@ -51,17 +52,23 @@ gint progress_timeout (gpointer pstru);
 void progress_createTimeout ();
 
 /* Set the total */
-void progress_setTotal (gulong total);
+void progress_setTotal (gulong total, gint reg);
 
 /* Set the current value */
-void progress_setCurrent (gulong current);
+void progress_setCurrent (gulong current, gint reg);
 /* Get The current value */
-gulong progress_getCurrent ();
+gulong progress_getCurrent (gint reg);
 
 /* Set a message in the appbar */
-void progress_setStatus(gchar *msg);
+void progress_setStatus(gchar *msg, gint reg);
 
 /* Set the gnome appbar to use */
-void progress_setGnomeAppBar(GtkWidget* appbar);
+void progress_setGnomeAppBar(GtkWidget* appbar, gint reg);
+
+/* Initializes the appbars handler */
+void progress_initGnomeAppBar ();
+
+/* Frees the appbars handler memory*/
+void progress_killGnomeAppBar ();
 
 #endif
