@@ -154,7 +154,8 @@ find_node_with_parent (GNode * parent, gchar * name,
   return (result);
 }
 
-gboolean find_files (GNode * gn, gpointer data)
+gboolean
+find_files (GNode * gn, gpointer data)
 {
   FOLDER *racine = data;
   const gchar *result[8];
@@ -166,8 +167,9 @@ gboolean find_files (GNode * gn, gpointer data)
   GString *current_filepath;
   gchar *gs_cat_replace, *gs_desc_replace;
 
-  progress_setCurrent (progress_getCurrent () + 1);
-  progress_timeout (NULL);
+  progress_setCurrent (progress_getCurrent (GNOMEAPPBAR_SEARCH) + 1,
+		       GNOMEAPPBAR_SEARCH);
+  progress_timeout (GINT_TO_POINTER (GNOMEAPPBAR_SEARCH));
   while (gtk_events_pending ())
     gtk_main_iteration ();
 
@@ -320,7 +322,8 @@ gboolean find_files (GNode * gn, gpointer data)
   return (FALSE);
 }
 
-gboolean simply_find_files (GNode * gn, gpointer data)
+gboolean
+simply_find_files (GNode * gn, gpointer data)
 {
   FOLDER *racine = data;
   const gchar *result[8];
@@ -329,8 +332,9 @@ gboolean simply_find_files (GNode * gn, gpointer data)
   gchar *nothing = " ";
   FILE_DATA *fd;
 
-  progress_setCurrent (progress_getCurrent () + 1);
-  progress_timeout (NULL);
+  progress_setCurrent (progress_getCurrent (GNOMEAPPBAR_SEARCH) + 1,
+		       GNOMEAPPBAR_SEARCH);
+  progress_timeout (GINT_TO_POINTER (GNOMEAPPBAR_SEARCH));
   while (gtk_events_pending ())
     gtk_main_iteration ();
 
@@ -395,9 +399,10 @@ start_search (FOLDER * racine, GNodeTraverseFunc cb_find_files)
 
   progress_reset ();
   progress_setTotal (g_node_n_nodes
-		     (SEARCH_OPTIONS_search_root, G_TRAVERSE_ALL));
-  progress_setCurrent (0);
-  progress_setStatus (_("Searching..."));
+		     (SEARCH_OPTIONS_search_root, G_TRAVERSE_ALL),
+		     GNOMEAPPBAR_SEARCH);
+  progress_setCurrent (0, GNOMEAPPBAR_SEARCH);
+  progress_setStatus (_("Searching..."), GNOMEAPPBAR_SEARCH);
 
   g_node_traverse (SEARCH_OPTIONS_search_root, G_PRE_ORDER, G_TRAVERSE_ALL,
 		   -1, cb_find_files, racine);
@@ -412,7 +417,8 @@ start_search (FOLDER * racine, GNodeTraverseFunc cb_find_files)
   reinit_thread_status ();
 }
 
-gint search_mode_from_text (gchar * text)
+gint
+search_mode_from_text (gchar * text)
 {
   gint i;
   i = 0;
@@ -962,12 +968,14 @@ cb_entry_NA1 (GtkWidget * w, gpointer data)
 	    {
 
 	      gtk_editable_set_editable (GTK_EDITABLE (entry), TRUE);
+	      gtk_widget_set_sensitive (GTK_WIDGET (entry), TRUE);
 	      gtk_entry_set_text (GTK_ENTRY (entry), *SEARCH_OPTION_str);
 	    }
 	}
       else
 	{
 	  gtk_editable_set_editable (GTK_EDITABLE (entry), FALSE);
+	  gtk_widget_set_sensitive (GTK_WIDGET (entry), FALSE);
 	  g_free (*SEARCH_OPTION_str);
 	  *SEARCH_OPTION_str =
 	    g_strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
@@ -979,6 +987,7 @@ cb_entry_NA1 (GtkWidget * w, gpointer data)
 void
 create_search_dialog (FOLDER * racine)
 {
+  GtkWidget *appbar1;
   GtkWidget *frame;
   GtkWidget *ok_button;
   GtkWidget *cancel_button;
@@ -1026,7 +1035,7 @@ create_search_dialog (FOLDER * racine)
   tcombo_items =
     g_list_append (tcombo_items, _(STRING_SM[REGULAR_EXPRESSION_CU]));
 
-  search_dialog_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  search_dialog_window = gnome_app_new (PACKAGE, _("Search"));
 
   gtk_window_set_transient_for (GTK_WINDOW (search_dialog_window),
 				GTK_WINDOW (main_window));
@@ -1034,16 +1043,27 @@ create_search_dialog (FOLDER * racine)
   gtk_widget_set_usize (GTK_WIDGET (search_dialog_window), 600, 350);
   gtk_window_set_position (GTK_WINDOW (search_dialog_window),
 			   GTK_WIN_POS_MOUSE);
-  gtk_window_set_title (GTK_WINDOW (search_dialog_window), _("Search"));
   gtk_window_set_policy (GTK_WINDOW (search_dialog_window), FALSE, TRUE,
 			 TRUE);
-  gtk_container_border_width (GTK_CONTAINER (search_dialog_window), 10);
   gtk_signal_connect (GTK_OBJECT (search_dialog_window), "delete_event",
 		      destroy_window, NULL);
 
-  notebook = gtk_notebook_new ();
-  gtk_container_add (GTK_CONTAINER (search_dialog_window), notebook);
+/* Status and progress bar */
+  appbar1 = gnome_appbar_new (TRUE, TRUE, GNOME_PREFERENCES_NEVER);
+  gtk_widget_ref (appbar1);
+  gtk_object_set_data_full (GTK_OBJECT (search_dialog_window),
+			    "appbar_search", appbar1,
+			    (GtkDestroyNotify) gtk_widget_unref);
+  gtk_widget_show (appbar1);
+  gnome_app_set_statusbar (GNOME_APP (search_dialog_window), appbar1);
+  progress_setGnomeAppBar (appbar1, GNOMEAPPBAR_SEARCH);
 
+
+
+  notebook = gtk_notebook_new ();
+  gnome_app_set_contents (GNOME_APP (search_dialog_window), notebook);
+
+/*********************************************************************/
 /* 1st page **********************************************************/
 /************** Simple search ****************************************/
 
@@ -1175,10 +1195,12 @@ create_search_dialog (FOLDER * racine)
   if (my_config->previous_search_mode == EVERYTHING_MATCHES)
     {
       gtk_entry_set_editable (GTK_ENTRY (es_entry), FALSE);
+	  gtk_widget_set_sensitive (GTK_WIDGET (es_entry), FALSE);
     }
   else
     {
       gtk_entry_set_editable (GTK_ENTRY (es_entry), TRUE);
+	  gtk_widget_set_sensitive (GTK_WIDGET (es_entry), TRUE);
     }
 
   s_path_tmenu = gtk_option_menu_new ();
@@ -1207,6 +1229,7 @@ create_search_dialog (FOLDER * racine)
 		    (GtkAttachOptions) (0), 0, 0);
 
   gtk_entry_set_editable (GTK_ENTRY (s_path_entry), FALSE);
+	  gtk_widget_set_sensitive (GTK_WIDGET (s_path_entry), FALSE);
 
   label = gtk_label_new (_("Name and location"));
   gtk_widget_show (label);
@@ -1377,6 +1400,7 @@ create_search_dialog (FOLDER * racine)
 		    (GtkAttachOptions) (0), 0, 0);
 
   gtk_entry_set_editable (GTK_ENTRY (desc_entry), FALSE);
+	  gtk_widget_set_sensitive (GTK_WIDGET (desc_entry), TRUE);
 
   info_tmenu = gtk_option_menu_new ();
   gtk_widget_show (info_tmenu);
@@ -1403,6 +1427,7 @@ create_search_dialog (FOLDER * racine)
 		    (GtkAttachOptions) (0), 0, 0);
 
   gtk_entry_set_editable (GTK_ENTRY (information_entry), FALSE);
+	  gtk_widget_set_sensitive (GTK_WIDGET (information_entry), TRUE);
 
   label = gtk_label_new (_("Description and Category"));
   gtk_widget_show (label);
